@@ -263,10 +263,6 @@ class RequestQueuer(object):
 
     def _checkActive(self):
         while self.getActive() < self.max_simul_reqs and self.getPending() > 0:     
-            LOGGER.critical("Active: %s, Max Simul: %s, Pending: %s" % (
-                self.getActive(),
-                self.max_simul_reqs,
-                self.getPending()))   
             hosts = self.pending_reqs.keys()
             dispatched_requests = False
             for host in hosts:
@@ -292,12 +288,22 @@ class RequestQueuer(object):
             self.getPending()))
                             
     def _requestComplete(self, response, deferred, host):
+        LOGGER.critical("Request complete for %s. (2) Active: %s, Max Simul: %s, Pending: %s" % (
+            host,
+            self.getActive(),
+            self.max_simul_reqs,
+            self.getPending()))
         self.active_reqs[host] -= 1
         self._checkActive()
         deferred.callback(response)
         return None
 
     def _requestError(self, error, deferred, host):
+        LOGGER.critical("Request error for %s. (2) Active: %s, Max Simul: %s, Pending: %s" % (
+            host,
+            self.getActive(),
+            self.max_simul_reqs,
+            self.getPending()))        
         self.active_reqs[host] -= 1
         self._checkActive()
         deferred.errback(error)
