@@ -196,6 +196,7 @@ class BaseServer(object):
             raise Exception(message)
     
     def callExposedFunction(self, func, kwargs, function_name, reservation_fast_cache=None, uuid=None):
+        LOGGER.critical("Executing %s" % function_name)
         if uuid is not None:
             self.active_jobs[uuid] = True
         if self.functions[function_name]["get_reservation_uuid"]:
@@ -221,12 +222,11 @@ class BaseServer(object):
             return d
         elif self.functions[function_name]["check_reservation_cache"]:
             kwargs["reservation_cache"] = None
-        d = deferToThread(func, **kwargs)
-        #d = maybeDeferred(func, **kwargs)
+        d = maybeDeferred(func, **kwargs)
         d.addCallback(self._callExposedFunctionCallback, function_name, uuid)
         d.addErrback(self._callExposedFunctionErrback, function_name, uuid)
         return d
-        
+            
     def _reservationCacheCallback(self, data, func, kwargs, function_name, uuid):
         LOGGER.debug("Got reservation cache for %s" % uuid)
         kwargs["reservation_cache"] = data
